@@ -5,8 +5,8 @@ from samtranslator.model.function_policies import FunctionPolicies, PolicyTypes,
 from samtranslator.model.exceptions import InvalidTemplateException
 from samtranslator.model.intrinsics import is_intrinsic_if, is_intrinsic_no_value
 
-class TestFunctionPolicies(TestCase):
 
+class TestFunctionPolicies(TestCase):
     def setUp(self):
         self.policy_template_processor_mock = Mock()
         self.is_policy_template_mock = Mock()
@@ -14,7 +14,6 @@ class TestFunctionPolicies(TestCase):
         self.function_policies = FunctionPolicies({}, self.policy_template_processor_mock)
         self.function_policies._is_policy_template = self.is_policy_template_mock
 
-
     @patch.object(FunctionPolicies, "_get_policies")
     def test_initialization_must_ingest_policies_from_resource_properties(self, get_policies_mock):
         resource_properties = {}
@@ -27,10 +26,9 @@ class TestFunctionPolicies(TestCase):
         get_policies_mock.assert_called_once_with(resource_properties)
         self.assertEqual(expected_length, len(function_policies))
 
-
     @patch.object(FunctionPolicies, "_get_policies")
     def test_get_must_yield_results_on_every_call(self, get_policies_mock):
-        resource_properties = {} # Just some input
+        resource_properties = {}  # Just some input
         dummy_policy_results = ["some", "policy", "statements"]
         expected_results = ["some", "policy", "statements"]
 
@@ -41,10 +39,9 @@ class TestFunctionPolicies(TestCase):
         # `list()` will implicitly call the `get()` repeatedly because it is a generator
         self.assertEqual(list(function_policies.get()), expected_results)
 
-
     @patch.object(FunctionPolicies, "_get_policies")
     def test_get_must_yield_no_results_with_no_policies(self, get_policies_mock):
-        resource_properties = {} # Just some input
+        resource_properties = {}  # Just some input
         dummy_policy_results = []
         expected_result = []
 
@@ -56,16 +53,12 @@ class TestFunctionPolicies(TestCase):
         self.assertEqual(list(function_policies.get()), expected_result)
 
     def test_contains_policies_must_work_for_valid_input(self):
-        resource_properties = {
-            "Policies": "some managed policy"
-        }
+        resource_properties = {"Policies": "some managed policy"}
 
         self.assertTrue(self.function_policies._contains_policies(resource_properties))
 
     def test_contains_policies_must_ignore_resources_without_policies(self):
-        resource_properties = {
-            "some key": "value"
-        }
+        resource_properties = {"some key": "value"}
 
         self.assertFalse(self.function_policies._contains_policies(resource_properties))
 
@@ -81,9 +74,7 @@ class TestFunctionPolicies(TestCase):
 
     def test_contains_policies_must_ignore_lowercase_property_name(self):
         # Property names are case sensitive
-        resource_properties = {
-            "policies": "some managed policy"
-        }
+        resource_properties = {"policies": "some managed policy"}
 
         self.assertFalse(self.function_policies._contains_policies(resource_properties))
 
@@ -96,9 +87,7 @@ class TestFunctionPolicies(TestCase):
 
     @patch("samtranslator.model.function_policies.is_instrinsic")
     def test_get_type_must_work_for_managed_policy_with_intrinsics(self, is_intrinsic_mock):
-        policy = {
-            "Ref": "somevalue"
-        }
+        policy = {"Ref": "somevalue"}
         expected = PolicyTypes.MANAGED_POLICY
         is_intrinsic_mock.return_value = True
 
@@ -106,18 +95,14 @@ class TestFunctionPolicies(TestCase):
         self.assertEqual(result, expected)
 
     def test_get_type_must_work_for_policy_statements(self):
-        policy = {
-            "Statement": "policy statements have a 'Statement' key"
-        }
+        policy = {"Statement": "policy statements have a 'Statement' key"}
         expected = PolicyTypes.POLICY_STATEMENT
 
         result = self.function_policies._get_type(policy)
         self.assertEqual(result, expected)
 
     def test_get_type_must_work_for_policy_templates(self):
-        policy = {
-            "PolicyTemplate": "some template"
-        }
+        policy = {"PolicyTemplate": "some template"}
         self.is_policy_template_mock.return_value = True
         expected = PolicyTypes.POLICY_TEMPLATE
 
@@ -125,9 +110,7 @@ class TestFunctionPolicies(TestCase):
         self.assertEqual(result, expected)
 
     def test_get_type_must_ignore_invalid_policy(self):
-        policy = {
-            "not-sure-what-this-is": "value"
-        }
+        policy = {"not-sure-what-this-is": "value"}
         # This is also not a policy template
         self.is_policy_template_mock.return_value = False
         expected = PolicyTypes.UNKNOWN
@@ -151,12 +134,10 @@ class TestFunctionPolicies(TestCase):
             {"Ref": "some managed policy"},
             {"Statement": "policy statement"},
             {"PolicyTemplate": "some value"},
-            ["unknown", "policy"]
+            ["unknown", "policy"],
         ]
-        resource_properties = {
-            "Policies": policies
-        }
-        self.is_policy_template_mock.side_effect = [True, False] # Return True for policy template, False for the list
+        resource_properties = {"Policies": policies}
+        self.is_policy_template_mock.side_effect = [True, False]  # Return True for policy template, False for the list
 
         expected = [
             PolicyEntry(data="managed policy 1", type=PolicyTypes.MANAGED_POLICY),
@@ -170,95 +151,60 @@ class TestFunctionPolicies(TestCase):
         self.assertEqual(result, expected)
 
     def test_get_policies_must_ignore_if_resource_does_not_contain_policy(self):
-        resource_properties = {
-        }
+        resource_properties = {}
         expected = []
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
 
     def test_get_policies_must_ignore_if_policies_is_empty(self):
-        resource_properties = {
-            "Policies": []
-        }
+        resource_properties = {"Policies": []}
         expected = []
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
 
     def test_get_policies_must_work_for_single_policy_string(self):
-        resource_properties = {
-            "Policies": "single managed policy"
-        }
-        expected = [
-            PolicyEntry(data="single managed policy", type=PolicyTypes.MANAGED_POLICY)
-        ]
+        resource_properties = {"Policies": "single managed policy"}
+        expected = [PolicyEntry(data="single managed policy", type=PolicyTypes.MANAGED_POLICY)]
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
 
     def test_get_policies_must_work_for_single_dict_with_managed_policy_intrinsic(self):
-        resource_properties = {
-            "Policies": {
-                "Ref": "some managed policy"
-            }
-        }
-        expected = [
-            PolicyEntry(data={"Ref": "some managed policy"}, type=PolicyTypes.MANAGED_POLICY)
-        ]
+        resource_properties = {"Policies": {"Ref": "some managed policy"}}
+        expected = [PolicyEntry(data={"Ref": "some managed policy"}, type=PolicyTypes.MANAGED_POLICY)]
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
 
     def test_get_policies_must_work_for_single_dict_with_policy_statement(self):
-        resource_properties = {
-            "Policies": {
-                "Statement": "some policy statement"
-            }
-        }
-        expected = [
-            PolicyEntry(data={"Statement": "some policy statement"}, type=PolicyTypes.POLICY_STATEMENT)
-        ]
+        resource_properties = {"Policies": {"Statement": "some policy statement"}}
+        expected = [PolicyEntry(data={"Statement": "some policy statement"}, type=PolicyTypes.POLICY_STATEMENT)]
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
 
     def test_get_policies_must_work_for_single_dict_of_policy_template(self):
-        resource_properties = {
-            "Policies": {
-                "PolicyTemplate": "some template"
-            }
-        }
+        resource_properties = {"Policies": {"PolicyTemplate": "some template"}}
         self.is_policy_template_mock.return_value = True
-        expected = [
-            PolicyEntry(data={"PolicyTemplate": "some template"}, type=PolicyTypes.POLICY_TEMPLATE)
-        ]
+        expected = [PolicyEntry(data={"PolicyTemplate": "some template"}, type=PolicyTypes.POLICY_TEMPLATE)]
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
         self.is_policy_template_mock.assert_called_once_with(resource_properties["Policies"])
 
     def test_get_policies_must_work_for_single_dict_of_invalid_policy_template(self):
-        resource_properties = {
-            "Policies": {
-                "InvalidPolicyTemplate": "some template"
-            }
-        }
-        self.is_policy_template_mock.return_value = False # Invalid policy template
-        expected = [
-            PolicyEntry(data={"InvalidPolicyTemplate": "some template"}, type=PolicyTypes.UNKNOWN)
-        ]
+        resource_properties = {"Policies": {"InvalidPolicyTemplate": "some template"}}
+        self.is_policy_template_mock.return_value = False  # Invalid policy template
+        expected = [PolicyEntry(data={"InvalidPolicyTemplate": "some template"}, type=PolicyTypes.UNKNOWN)]
 
         result = self.function_policies._get_policies(resource_properties)
         self.assertEqual(result, expected)
         self.is_policy_template_mock.assert_called_once_with({"InvalidPolicyTemplate": "some template"})
 
     def test_get_policies_must_work_for_unknown_policy_types(self):
-        resource_properties = {
-            "Policies": [
-                1, 2, 3
-            ]
-        }
+        resource_properties = {"Policies": [1, 2, 3]}
         expected = [
             PolicyEntry(data=1, type=PolicyTypes.UNKNOWN),
             PolicyEntry(data=2, type=PolicyTypes.UNKNOWN),
@@ -272,11 +218,7 @@ class TestFunctionPolicies(TestCase):
 
     def test_is_policy_template_must_detect_valid_policy_templates(self):
         template_name = "template_name"
-        policy = {
-            template_name: {
-                "Param1": "foo"
-            }
-        }
+        policy = {template_name: {"Param1": "foo"}}
 
         self.policy_template_processor_mock.has.return_value = True
         function_policies = FunctionPolicies({}, self.policy_template_processor_mock)
@@ -286,7 +228,7 @@ class TestFunctionPolicies(TestCase):
         self.policy_template_processor_mock.has.assert_called_once_with(template_name)
 
     def test_is_policy_template_must_ignore_non_dict_policies(self):
-        policy = [1,2,3]
+        policy = [1, 2, 3]
 
         self.policy_template_processor_mock.has.return_value = True
         function_policies = FunctionPolicies({}, self.policy_template_processor_mock)
@@ -303,10 +245,7 @@ class TestFunctionPolicies(TestCase):
 
     def test_is_policy_template_must_ignore_dict_with_two_keys(self):
         template_name = "template_name"
-        policy = {
-            template_name: {"param1": "foo"},
-            "A": "B"
-        }
+        policy = {template_name: {"param1": "foo"}, "A": "B"}
 
         self.policy_template_processor_mock.has.return_value = True
 
@@ -315,9 +254,7 @@ class TestFunctionPolicies(TestCase):
 
     def test_is_policy_template_must_ignore_non_policy_templates(self):
         template_name = "template_name"
-        policy = {
-            template_name: {"param1": "foo"}
-        }
+        policy = {template_name: {"param1": "foo"}}
 
         self.policy_template_processor_mock.has.return_value = False
 
@@ -327,56 +264,38 @@ class TestFunctionPolicies(TestCase):
         self.policy_template_processor_mock.has.assert_called_once_with(template_name)
 
     def test_is_policy_template_must_return_false_without_the_processor(self):
-        policy = {
-            "template_name": {"param1": "foo"}
-        }
+        policy = {"template_name": {"param1": "foo"}}
 
-        function_policies_obj = FunctionPolicies({}, None) # No policy template processor
+        function_policies_obj = FunctionPolicies({}, None)  # No policy template processor
 
         self.assertFalse(function_policies_obj._is_policy_template(policy))
         self.policy_template_processor_mock.has.assert_not_called()
 
     def test_is_intrinsic_if_must_return_true_for_if(self):
-        policy = {
-            "Fn::If": "some value"
-        }
+        policy = {"Fn::If": "some value"}
 
         self.assertTrue(is_intrinsic_if(policy))
 
     def test_is_intrinsic_if_must_return_false_for_others(self):
-        too_many_keys = {
-            "Fn::If": "some value",
-            "Fn::And": "other value"
-        }
+        too_many_keys = {"Fn::If": "some value", "Fn::And": "other value"}
 
-        not_if = {
-            "Fn::Or": "some value"
-        }
+        not_if = {"Fn::Or": "some value"}
 
         self.assertFalse(is_intrinsic_if(too_many_keys))
         self.assertFalse(is_intrinsic_if(not_if))
         self.assertFalse(is_intrinsic_if(None))
 
     def test_is_intrinsic_no_value_must_return_true_for_no_value(self):
-        policy = {
-            "Ref": "AWS::NoValue"
-        }
+        policy = {"Ref": "AWS::NoValue"}
 
         self.assertTrue(is_intrinsic_no_value(policy))
 
     def test_is_intrinsic_no_value_must_return_false_for_other_value(self):
-        bad_key = {
-            "sRefs": "AWS::NoValue"
-        }
+        bad_key = {"sRefs": "AWS::NoValue"}
 
-        bad_value = {
-            "Ref": "SWA::NoValue"
-        }
+        bad_value = {"Ref": "SWA::NoValue"}
 
-        too_many_keys = {
-            "Ref": "AWS::NoValue",
-            "feR": "SWA::NoValue"
-        }
+        too_many_keys = {"Ref": "AWS::NoValue", "feR": "SWA::NoValue"}
 
         self.assertFalse(is_intrinsic_no_value(bad_key))
         self.assertFalse(is_intrinsic_no_value(bad_value))
@@ -384,17 +303,11 @@ class TestFunctionPolicies(TestCase):
         self.assertFalse(is_intrinsic_no_value(too_many_keys))
 
     def test_get_type_with_intrinsic_if_must_return_managed_policy_type(self):
-        managed_policy = {
-            "Fn::If": ["SomeCondition", "some managed policy arn", "other managed policy arn"]
-        }
+        managed_policy = {"Fn::If": ["SomeCondition", "some managed policy arn", "other managed policy arn"]}
 
-        no_value_if = {
-            "Fn::If": ["SomeCondition", {"Ref": "AWS::NoValue"}, "other managed policy arn"]
-        }
+        no_value_if = {"Fn::If": ["SomeCondition", {"Ref": "AWS::NoValue"}, "other managed policy arn"]}
 
-        no_value_else = {
-            "Fn::If": ["SomeCondition", "other managed policy arn", {"Ref": "AWS::NoValue"}]
-        }
+        no_value_else = {"Fn::If": ["SomeCondition", "other managed policy arn", {"Ref": "AWS::NoValue"}]}
 
         expected_managed_policy = PolicyTypes.MANAGED_POLICY
 
@@ -407,13 +320,9 @@ class TestFunctionPolicies(TestCase):
             "Fn::If": ["SomeCondition", {"Statement": "then statement"}, {"Statement": "else statement"}]
         }
 
-        no_value_if = {
-            "Fn::If": ["SomeCondition", {"Ref": "AWS::NoValue"}, {"Statement": "else statement"}]
-        }
+        no_value_if = {"Fn::If": ["SomeCondition", {"Ref": "AWS::NoValue"}, {"Statement": "else statement"}]}
 
-        no_value_else = {
-            "Fn::If": ["SomeCondition", {"Statement": "then statement"}, {"Ref": "AWS::NoValue"}]
-        }
+        no_value_else = {"Fn::If": ["SomeCondition", {"Statement": "then statement"}, {"Ref": "AWS::NoValue"}]}
         expected_managed_policy = PolicyTypes.POLICY_STATEMENT
 
         self.assertTrue(expected_managed_policy, self.function_policies._get_type(policy_statement))
@@ -422,23 +331,14 @@ class TestFunctionPolicies(TestCase):
 
     def test_get_type_with_intrinsic_if_must_return_policy_template_type(self):
         policy_template = {
-            "Fn::If": [ "SomeCondition",
-                        {"template_name_one": { "Param1": "foo"}},
-                        {"template_name_one": { "Param1": "foo"}}
-                        ]
-        }
-        no_value_if = {
-            "Fn::If": [ "SomeCondition",
-                        {"Ref": "AWS::NoValue"},
-                        {"template_name_one": { "Param1": "foo"}}
-                        ]
-        }
-        no_value_else = {
-            "Fn::If": [ "SomeCondition",
-                        {"template_name_one": { "Param1": "foo"}},
-                        {"Ref": "AWS::NoValue"}
-                        ]
+            "Fn::If": [
+                "SomeCondition",
+                {"template_name_one": {"Param1": "foo"}},
+                {"template_name_one": {"Param1": "foo"}},
+            ]
         }
+        no_value_if = {"Fn::If": ["SomeCondition", {"Ref": "AWS::NoValue"}, {"template_name_one": {"Param1": "foo"}}]}
+        no_value_else = {"Fn::If": ["SomeCondition", {"template_name_one": {"Param1": "foo"}}, {"Ref": "AWS::NoValue"}]}
 
         expected_managed_policy = PolicyTypes.POLICY_TEMPLATE
         self.policy_template_processor_mock.has.return_value = True
@@ -449,24 +349,16 @@ class TestFunctionPolicies(TestCase):
         self.assertTrue(expected_managed_policy, function_policies._get_type(no_value_else))
 
     def test_get_type_with_intrinsic_if_must_raise_exception_for_bad_policy(self):
-        policy_too_few_values = {
-            "Fn::If": ["condition", "then"]
-        }
+        policy_too_few_values = {"Fn::If": ["condition", "then"]}
 
-        policy_too_many_values = {
-            "Fn::If": ["condition", "then", "else", "extra"]
-        }
+        policy_too_many_values = {"Fn::If": ["condition", "then", "else", "extra"]}
 
         self.assertRaises(InvalidTemplateException, self.function_policies._get_type, policy_too_few_values)
         self.assertRaises(InvalidTemplateException, self.function_policies._get_type, policy_too_many_values)
 
     def test_get_type_with_intrinsic_if_must_raise_exception_for_different_policy_types(self):
-        policy_one = {
-            "Fn::If": ["condition", "then", {"Statement": "else"}]
-        }
-        policy_two = {
-            "Fn::If": ["condition", {"Statement": "then"}, "else"]
-        }
+        policy_one = {"Fn::If": ["condition", "then", {"Statement": "else"}]}
+        policy_two = {"Fn::If": ["condition", {"Statement": "then"}, "else"]}
 
         self.assertRaises(InvalidTemplateException, self.function_policies._get_type, policy_one)
-        self.assertRaises(InvalidTemplateException, self.function_policies._get_type, policy_two)
\ No newline at end of file
+        self.assertRaises(InvalidTemplateException, self.function_policies._get_type, policy_two)
